==> bitcoin-0.13.2.tar.gz: bitcoin-0.13.2/src/qt/locale/bitcoin_cs_CZ.ts <==
<TS language="cs_CZ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Pravým klikem editujte adresu nebo popisek</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Vytvořit novou adresu</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopírovat aktuálně vybrané adresy do schránky</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Odstraní aktuálně vybrané adresy ze seznamu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportovat aktuální pohled do souboru</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportovat</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Odstranit</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Zadej heslo</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nové heslo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Zopakujte nové heslo</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchronizuji se sítí...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Přehled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Zobrazit základní přehled o peněžence</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakce</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Procházení historií transakcí</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Možnosti...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Změnit heslo k šifrování peněženky</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Panely</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aktuální</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Zachytávám...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Odeslané transakce</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Příchozí transakce</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Peněženka je &lt;b&gt;zašifrována&lt;/b&gt; a momentálně &lt;b&gt;odemčená&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Peněženka je &lt;b&gt;zašifrována&lt;/b&gt; a momentálně &lt;b&gt;uzamčená&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Množství:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrzeno</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Upravit adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Popisek</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Použití:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapovat port pomocí &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimalizovat do systémové lišty (tray) namísto do hlavního panelu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimalizovat při zavření</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Popisek:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>Zpráva:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Množství:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Zůstatek:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Popisek:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Zpráva:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Toto podokno zobrazuje detailní popis transakce</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Načítání adres...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Načítání peněženky...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Načítání dokončeno</translation>
    </message>
    </context>
</TS>

==> bitcoin-0.16.2.tar.gz: bitcoin-0.16.2/src/qt/locale/bitcoin_cs_CZ.ts <==
<TS language="cs_CZ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Pravým klikem editujte adresu nebo popisek</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Vytvořit novou adresu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopírovat aktuálně vybrané adresy do schránky</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovat</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Odstraní aktuálně vybrané adresy ze seznamu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportovat aktuální pohled do souboru</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportovat</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Textový soubor oddělený středníkem (*.csv)</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Zadej heslo</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nové heslo</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Zopakujte nové heslo</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Zašifrovat peněženku</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Tato operace vyžaduje heslo k odemknutí peněženky.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Odemknout peněženku</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Tato operace vyžaduje heslo k dešifrování peněženky.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dešifrovat peněženku</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Změnit heslo</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Potvrďte zašifrování peněženky</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Peněženka zašifrována</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Zašifrování peněženky selhalo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Šifrování peněženky selhalo vinou vnitřní chyby. Vaše peněženka nebyla zašifrována.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Zadaná hesla nejsou shodná.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Odemčení peněženky selhalo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Heslo zadané k dešifrování peněženky nebylo správné</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Deěifrování peněženky selhalo</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Synchronizuji se sítí...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Přehled</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Zobrazit základní přehled o peněžence</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transakce</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Procházení historií transakcí</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Možnosti...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Změnit heslo k šifrování peněženky</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Panely</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Aktuální</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Zachytávám...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Odeslané transakce</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Příchozí transakce</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Peněženka je &lt;b&gt;zašifrována&lt;/b&gt; a momentálně &lt;b&gt;odemčená&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Peněženka je &lt;b&gt;zašifrována&lt;/b&gt; a momentálně &lt;b&gt;uzamčená&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Množství:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrzeno</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopírovat sdresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopírovat popis</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Upravit adresu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Popisek</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nová adresa pro příjem</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nová adresa k odeslání</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Upravit adresu pro příjem</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Upravit adresu k odeslání</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Zadaná adresa "%1" se již v seznamu adres nachází.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nemohu odemknout peněženku</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generování nového klíče selhalo.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Použití:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapovat port pomocí &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimalizovat do systémové lišty (tray) namísto do hlavního panelu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimalizovat při zavření</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Popisek:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>Zpráva:</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopírovat popis</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Množství:</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Zůstatek:</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Částka k zaplacení musí být větší než 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Popisek:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Zpráva:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1 potvrzeno</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 potvrzení</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Zpráva</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transakce</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Množství</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Toto podokno zobrazuje detailní popis transakce</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Potvrzeno (%1 potvrzení)</translation>
    </message>
    <message>
        <source>This block was not received by any other nodes and will probably not be accepted!</source>
        <translation>Tento blok nebyl přijat žádným dalším uzlem a pravděpodobně nebude akceptován!</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Přijato s</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Odesláno na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Platba sobě samému</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Vytěženo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(bez popisu)</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Typ transakce.</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dnes</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Tento týden</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Tento měsíc</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Minulý měsíc</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Tento rok</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Rozsah...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Přijato s</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Odesláno na</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Sobě samému</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Vytěženo</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ostatní</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min. množství</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopírovat sdresu</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopírovat popis</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Upravit popis</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Textový soubor oddělený středníkem (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potvrzeno</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Rozsah:</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportovat</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportovat aktuální pohled do souboru</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Načítání peněženky...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Načítání dokončeno</translation>
    </message>
    </context>
</TS>
